@@ -7,15 +7,23 @@ require Exporter;
 );
 use warnings;
 use strict;
-our $VERSION = '0.22';
+our $VERSION = '0.23';
+
 # Are we running as XS?
+
 our $noxs;
+
+# The environment variable JSONCreatePP controls whether this runs as
+# XS or purely Perl.
+
 $noxs = $ENV{JSONCreatePP};
+
 # Did the XS load OK?
+
 our $xsok;
+
 if (! $noxs) {
     eval {
-	#    die;
 	require XSLoader;
 	XSLoader::load ('JSON::Create', $VERSION);
 	$xsok = 1;
@@ -24,8 +32,8 @@ if (! $noxs) {
 	$xsok = 0;
     }
 }
+
 if (! $xsok || $noxs) {
-#    print "Pure perl OK.\n";
     require JSON::Create::PP;
     JSON::Create::PP->import (':all');
 }
@@ -45,7 +53,6 @@ sub set_fformat
 	    $obj->set_fformat_unsafe (0);
 	}
 	else {
-	    print "$fformat\n";
 	    $obj->set_fformat_unsafe ($fformat);
 	}
     }
